@@ -106,7 +106,7 @@ static void gpd_pilot_info_check (GtkEditable *editable, gpointer user_data);
 static void gpd_pilot_info_button (GtkToggleButton *toggle, gpointer user_data);
 
 static void gpd_request_completed (GnomePilotClient* client, const gchar *id, gint handle, gpointer user_data);
-static void gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_Pilot_PilotUser *user, gpointer user_data);
+static void gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_Pilot_UserInfo *user, gpointer user_data);
 
 static void gpd_destroy (GtkObject *object);
 
@@ -180,9 +180,6 @@ init (GnomePilotDruid *gpd)
 	fill_widgets (gpd);
 	init_widgets (gpd);
 
-	priv->state->pilots = g_list_append (priv->state->pilots, priv->pilot);
-	priv->state->devices = g_list_append (priv->state->devices, priv->device);
-
  error:
 }
 
@@ -477,12 +474,13 @@ gpd_sync_page_prepare (GnomeDruidPage *page, gpointer arg1, gpointer user_data)
 
 	GnomePilotDruid *gpd = GNOME_PILOT_DRUID (user_data);
 	GnomePilotDruidPrivate *priv;
-	GNOME_Pilot_PilotUser user;
+	GNOME_Pilot_UserInfo user;
 	gchar *text;
 
 	priv = gpd->priv;
 
 	read_device_config (GTK_OBJECT (gpd), priv->device);
+	priv->state->devices = g_list_append (priv->state->devices, priv->device);
 
 	if (GTK_TOGGLE_BUTTON (priv->pilot_info_no)->active) {
 		/* do send_to_pilot */
@@ -566,6 +564,7 @@ gpd_finish_page_finished (GnomeDruidPage *druidpage, gpointer arg1, gpointer use
 	priv = gpd->priv;
 	
 	read_pilot_config (GTK_OBJECT (gpd), priv->pilot);
+	priv->state->pilots = g_list_append (priv->state->pilots, priv->pilot);
 	
 	save_config_and_restart (priv->gpc, priv->state);
 	
@@ -633,7 +632,7 @@ gpd_request_completed (GnomePilotClient* client, const gchar *id, gint handle, g
 }
 
 static void 
-gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_Pilot_PilotUser *user, gpointer user_data) 
+gpd_userinfo_requested (GnomePilotClient *gpc, const gchar *device, const GNOME_Pilot_UserInfo *user, gpointer user_data) 
 {
 	GnomePilotDruid *gpd = GNOME_PILOT_DRUID (user_data);
 	GnomePilotDruidPrivate *priv;
