@@ -24,8 +24,10 @@
 
 #include <stdio.h>
 #include <sys/stat.h>
+#include <errno.h>
 #include <ctype.h>
 #include <glade/glade.h>
+#include <errno.h>
 #include "util.h"
 
 static const guint speedList[] = {9600, 19200, 38400, 57600, 115200, 0};
@@ -108,7 +110,6 @@ fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
 	
 	menu = GTK_MENU (gtk_menu_new ());
 
-	/* Add the disabled item first. */
 	menu_item = gtk_menu_item_new_with_label(_("Disabled"));
 	gtk_widget_show(menu_item);
 	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
@@ -140,6 +141,37 @@ fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
 	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
 }
 
+void 
+fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
+{
+	GtkWidget *menu_item;
+	GtkMenu   *menu;
+	GList *tmp;
+	int index, current=0;
+	
+	menu = GTK_MENU (gtk_menu_new ());
+
+	menu_item = gtk_menu_item_new_with_label(_("None"));
+	gtk_widget_show(menu_item);
+	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
+	gtk_menu_append (menu, menu_item);
+
+	tmp = state->valid_synctypes;
+	for (index = 0; tmp != NULL; tmp = tmp->next, index++) {
+		gint value = GPOINTER_TO_INT (tmp->data);
+		
+		menu_item = gtk_menu_item_new_with_label (sync_type_to_str (value));
+		gtk_widget_show (menu_item);
+		gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (value));
+		gtk_menu_append (menu,menu_item);
+		if (value == state->first_sync_type) 
+			current = index + 1;
+	}
+
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), GTK_WIDGET (menu));
+	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
+}
+
 void
 show_popup_menu (GtkCList *list, GdkEventButton *event, GtkMenu *menu)
 {
@@ -418,7 +450,7 @@ const gchar*
 device_type_to_str (GPilotDeviceType t) 
 {
 	switch (t) {
-	case PILOT_DEVICE_USB_VISOR: return _("Handspring USB");
+	case PILOT_DEVICE_USB_VISOR: return _("USB");
 	case PILOT_DEVICE_IRDA:      return _("IrDA");
 	case PILOT_DEVICE_NETWORK:   return _("Network");
 	default:                     return _("Serial");
@@ -590,8 +622,7 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 {
 	savePilotState (state);
 	/* FORCE the gpilotd to reread the settings */
-	gnome_pilot_client_pause_daemon (gpc);
-	gnome_pilot_client_unpause_daemon (gpc);
+	gnome_pilot_client_restart_daemon (gpc);
 }
 
 void 
