@@ -23,36 +23,43 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 
+/* for crypt () */
 #ifdef USE_XOPEN_SOURCE
+#ifndef _XOPEN_SOURCE
 #define _XOPEN_SOURCE 
+#endif /* _XOPEN_SOURCE  */
 #endif
 
 #include <sys/types.h>
+#include <sys/stat.h>
+#include <sys/wait.h>
+#include <sys/time.h>
+
+#include <glib.h>
 #include <pwd.h>
 #include <errno.h>
-#include <sys/time.h>
-#include <glib.h>
-#include "manager.h"
-#include <libgnome/libgnome.h>
 #include <string.h>
-#include "gnome-pilot-structures.h"
-#include <unistd.h>
 #include <signal.h>
+#include <unistd.h>
+#include <stdio.h>
+#include <fcntl.h>
+
+#include <libgnome/libgnome.h>
+
 #include <pi-source.h>
 #include <pi-dlp.h>
 #include <pi-version.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-#include <pwd.h>
-#include <unistd.h>
 
+#include "manager.h"
+#include "gnome-pilot-structures.h"
 #include "orbit_daemon_glue.h"
 #include "gpilot-gui.h"
-#include <errno.h>
-
 #include "gnome-pilot-conduit-backup.h"
+
 #include <libgpilotdCM/gnome-pilot-conduit-management.h>
 
 /* Set to true when the config should be reloaded */
@@ -112,20 +119,20 @@ static int
 pilot_connect (GPilotDevice *device,int *error) 
 {
 	struct pi_sockaddr addr;
-	int sd;
+	int sd, listen_sd;
 	int ret;
     
 	if (device->type != PILOT_DEVICE_NETWORK) {
 		pilot_set_baud_rate (device);
 	}
 
-	if (!(sd = pi_socket (PI_AF_SLP, PI_SOCK_STREAM, PI_PF_PADP))) {
+	if (!(listen_sd = pi_socket (PI_AF_PILOT, PI_SOCK_STREAM, PI_PF_DLP))) {
 		g_warning ("pi_socket: %s",strerror (errno));
 		if (error) *error = 1;
 		return -1;
 	}
 	
-	addr.pi_family = PI_AF_SLP;
+	addr.pi_family = PI_AF_PILOT;
 
 /*
 	Most important for networking
@@ -134,34 +141,43 @@ pilot_connect (GPilotDevice *device,int *error)
 	so don't really need to do it again here.
 */
 	if (device->type == PILOT_DEVICE_NETWORK) {
-		device->port = ".";
+		device->port = "net:any";
 	}
 
 	strcpy (addr.pi_device,device->port);
 
-	ret = pi_bind (sd, (struct sockaddr*)&addr, sizeof (addr));
+	ret = pi_bind (listen_sd, (struct sockaddr*)&addr, sizeof (addr));
 	if (ret == -1) {
 		g_warning (_("Unable to bind to pilot"));
-		if (error) *error = 1;
+		if (error)
+			*error = 1;
+		pi_close(listen_sd);
 		return 0;
 	}
 
-	ret = pi_listen (sd,1);
+	ret = pi_listen (listen_sd, 1);
 	if (ret != 0) {
 		g_warning ("pi_listen: %s", strerror (errno));
-		if (error) *error = 2;
+		if (error)
+			*error = 2;
+		pi_close(listen_sd);
 		return 0;
 	}
 
-	sd = pi_accept_to (sd, NULL,0, device->timeout); 
+	sd = pi_accept_to (listen_sd, NULL,0, device->timeout); 
 	if (sd == -1) {
 		g_warning ("pi_accept_to: %s", strerror (errno));
 		g_warning ("pi_accept_to: timeout was %d secs", device->timeout);
-		if (error) *error = 2;
+		if (error)
+			*error = 2;
+		pi_close(listen_sd);
 		return 0;
 	}
 
-	if (error) *error = 0;
+	if (error)
+		*error = 0;
+	pi_close(listen_sd);
+	
 	return sd;
 }
 
@@ -537,8 +553,9 @@ gpilot_syncing_known_pilot (GPilotPilot *pilot,
 {
 	struct stat buf; 
 	int ret;
-	
-	ret=stat (pilot->sync_options.basedir, &buf); 
+		
+	ret = stat (pilot->sync_options.basedir, &buf); 
+
 	if (ret < 0 || !( S_ISDIR (buf.st_mode) && (buf.st_mode & (S_IRUSR | S_IWUSR |S_IXUSR))) ) {
 		
 		g_message ("Invalid basedir: %s", pilot->sync_options.basedir);
@@ -627,7 +644,6 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 			}
 		}
 		pilot_disconnect (pfd);
-		close (pfd);
 	} else {
 		if (connect_error==1) return FALSE; /* remove this device */
 		else return TRUE;
@@ -796,12 +812,22 @@ network_device_err (GIOChannel *io_channel,
 
 #ifdef WITH_USB_VISOR
 #ifdef linux
+static const char *product_names[] =
+{
+	"Handspring Visor",
+	"Handspring Treo",
+	"Palm Handheld",
+	NULL
+};
+
+
 static gboolean 
 visor_devices_in (GIOChannel *io_channel,
 		 GIOCondition condition,
 		 GPilotContext *context) {
 	GPilotDevice *device;
-	GList *i;
+	GList *l;
+	int i;
 	gboolean visor_exists = FALSE;
 	char line[256]; /* this is more than enough to fit any line from 
 			 * /proc/bus/usb/devices */
@@ -817,32 +843,32 @@ visor_devices_in (GIOChannel *io_channel,
 
 	/* Check /proc/bus/usb/devices for a visor */
 	f = fopen ("/proc/bus/usb/devices", "r");
-
-	fgets (line, 255, f);
-	while (!feof (f)) {
-		if (line[0] == 'S') {
-			if (!strncmp (line + 4, "Product=Handspring Visor",
-				      24)) {
+	
+	while (fgets (line, 255, f) != NULL && !visor_exists) {
+		if (line[0] != 'S')
+			continue;
+		
+		for (i = 0; product_names[i] != NULL; i++) {
+			if (!strncmp (line + strlen ("S:  Product="), 
+				      product_names[i], 
+				      strlen (product_names[i])))
 				visor_exists = TRUE;
-				break;
-			}
 		}
-		fgets (line, 255, f);
 	}
 	
 	fclose (f);
 	
 	if (visor_exists) {
-		i = context->devices;
-		while (i) {
-			device = i->data;
+		l = context->devices;
+		while (l) {
+			device = l->data;
 			if (device->type == PILOT_DEVICE_USB_VISOR) {
 				/* just try to synch.  Until I can talk to 
 				 * the kernel guys this is the best way to 
                                  * go. */
 				sync_device (device, context);
 			}
-			i = i->next;
+			l = l->next;
 		}
 	}
 
@@ -966,6 +992,7 @@ remove_pid_file () {
 					   strlen ("/.gpilotd.pid") + 1);
 		strcpy (pid_file,home_directory);
 		strcat (pid_file,"/.gpilotd.pid");
+
 		if (access (pid_file,R_OK|W_OK)==0) {
 			unlink (pid_file);
 		} 
