@@ -75,7 +75,7 @@ typedef struct {
 typedef gint (*iterate_func)(GnomePilotConduitStandard *, GnomePilotDBInfo *);
 
 /* Prototypes */
-static void unload_foreach (GnomePilotConduit *conduit, gpointer unused);
+static void gpilot_unload_conduit_foreach (GnomePilotConduit *conduit, gpointer unused);
 static gint find_matching_conduit_compare_func (GnomePilotConduit *a,
 						GnomePilotDBInfo *b);
 static GnomePilotConduit *find_matching_conduit (GList *conlist, GnomePilotDBInfo *dbinfo);
@@ -617,8 +617,8 @@ do_restore_foreach (GPilotRequest *req, GnomePilotInstallCarrier *carrier)
 }
 
 static void
-unload_foreach (GnomePilotConduit *conduit,
-	       gpointer unused)
+gpilot_unload_conduit_foreach (GnomePilotConduit *conduit,
+			       gpointer unused)
 {
 	GnomePilotConduitManagement *manager;
 	g_return_if_fail (conduit != NULL);
@@ -711,7 +711,7 @@ gpilot_load_conduits (GPilotContext *context,
 void
 gpilot_unload_conduits (GList *list)
 {
-	g_list_foreach (list, (GFunc) unload_foreach, NULL);
+	g_list_foreach (list, (GFunc) gpilot_unload_conduit_foreach, NULL);
 	g_list_free (list);
 }
 
